@@ -22,10 +22,10 @@
 
 #define CHAR_WIDTH 5
 #define CHAR_HEIGHT 7
-#define VERSION "2.4"
+#define VERSION "2.8"
 #define _MULTI_THREADED
 
-typedef enum {NONE, ALARM, TIMER, CHRONO_PAUSED, CHRONO_ACTIVE} modeType;
+typedef enum {NONE, ALARM, TIMER, TIMER_DONE, CHRONO_PAUSED, CHRONO_ACTIVE} modeType;
 typedef enum {BELL, COMMAND} actionType;
 typedef enum {OUT, IN, RETURN} configState;
 
@@ -68,6 +68,7 @@ static GtkWidget *spinner1;
 static GtkWidget *spinner2;
 static GtkWidget *spinner3;
 
+int timeSetToZero = 0;
 int buttonStatus = -1;
 int hour = 0, min = 0, sec = 0;
 char *myName;
@@ -112,6 +113,9 @@ int main(int argc, char *argv[])
   updateMain();
   updateACT(); 
 
+  if (hour == 0 && min == 0 && sec == 0) 
+    timeSetToZero = 1;
+
   while (1) 
   {
     now = time(0);
@@ -128,8 +132,8 @@ int main(int argc, char *argv[])
 	{
 	  decrementTimer();
 	  updateACT();
-	  if (hour == 0 && min == 0 && sec == 0)
-	    execAct();
+	  if (hour == 0 && min == 0 && sec == 0 && !timeSetToZero)
+	      execAct();
 	}
 	prevSec = thisTime->tm_sec;
 	break;
@@ -148,7 +152,7 @@ int main(int argc, char *argv[])
 	  execAct();
 	break;
       case NONE:
-	break;
+      case TIMER_DONE:
       case CHRONO_PAUSED:
 	break;
     }
@@ -186,7 +190,12 @@ void execAct()
     printf("\07");
     fflush(stdout);
   }
-  mode = NONE;
+
+  if (mode == TIMER)
+    mode = TIMER_DONE;	// Don't want to keep doing the Timer event
+  else
+    mode = NONE;
+
 }
 
 
@@ -338,6 +347,7 @@ void processEvent(XEvent *event)
 	      hour = min = sec = 0;
 	      updateACT();
 	    }
+	    timeSetToZero = 0;
 	    mode = CHRONO_ACTIVE;
 	    updateMain();
 	    break;
@@ -557,13 +567,16 @@ void callback(GtkWidget * widget, gpointer data)
     hour = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (spinner1));
     min = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (spinner2));
     sec = gtk_spin_button_get_value_as_int(GTK_SPIN_BUTTON (spinner3));
+    timeSetToZero = 0;
 
     // If users presses 'ok' and we have not explicitly set the mode, 
     // then it was left on ALARM
-    if (!tmpMode)
-      tmpMode = 1;
+//    if (!tmpMode)
+//      tmpMode = 1;
 
     mode = tmpMode;
+    // need to reset so that it can default to ALARM if timer not specified 
+//    tmpMode = NONE;
     action = tmpAction;
     configSt = RETURN;
   }
@@ -645,7 +658,6 @@ void *configure(void *arg)
   gtk_box_pack_start (GTK_BOX (box2), button, FALSE, FALSE, 2);
   gtk_widget_show (button);
 
-
   // Create Timer radio button
   button = gtk_radio_button_new_with_label (gtk_radio_button_group
       (GTK_RADIO_BUTTON (button)), "Timer");
@@ -656,7 +668,7 @@ void *configure(void *arg)
   gtk_widget_show (box2);
 
   // If we are in timer mode, set toggle accordingly else default to alarm 
-  if (mode == TIMER)	
+  if (mode == TIMER || mode == TIMER_DONE)
     gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (button), TRUE);
 
   // Create frame for the time 
